"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const contentWriter_1 = require("../init/helpers/contentWriter");
const www_1 = require("../init/www/www");
const PROJECT_DIR = ({ appName }) => __awaiter(void 0, void 0, void 0, function* () {
    const { metadata } = yield (0, www_1.wwwFileCreator)({ appName });
    return {
        root: {
            folder: "root",
            files: [
                {
                    app: { fileName: "app.js", content: contentWriter_1.App.app },
                    package: {
                        fileName: "package.json",
                        content: (0, contentWriter_1.PackageJson)({ appName }),
                    },
                    gitignore: { fileName: ".gitignore", content: contentWriter_1.gitFile.gitIgnore },
                },
            ],
        },
        bin: {
            folder: "bin",
            files: [{ www: { fileName: "www", content: metadata } }],
        },
        src: {
            folder: "src",
            files: [
                {
                    folder: "config",
                    files: [
                        {
                            index: { fileName: "index.js", content: contentWriter_1.config.index },
                            constants: {
                                fileName: "constants.js",
                                content: contentWriter_1.config.constants,
                            },
                            httpCodes: {
                                fileName: "httpCodes.js",
                                content: contentWriter_1.config.httpCodes,
                            },
                            messages: { fileName: "messages.js", content: contentWriter_1.config.messages },
                        },
                    ],
                },
                {
                    folder: "helpers",
                    files: [
                        {
                            index: { fileName: "index.js", content: contentWriter_1.helpers.index },
                            response: { fileName: "response.js", content: contentWriter_1.helpers.response },
                            routeHandler: {
                                fileName: "routeHandler.js",
                                content: contentWriter_1.helpers.routeHandler,
                            },
                            errorHandler: {
                                fileName: "errorHandler.js",
                                content: contentWriter_1.helpers.errorHandler,
                            },
                            errorResponse: {
                                folder: "errorResponse",
                                files: [
                                    {
                                        index: {
                                            fileName: "index.js",
                                            content: contentWriter_1.helpers.errorResponse.index,
                                        },
                                        badRequest: {
                                            fileName: "badRequest.js",
                                            content: contentWriter_1.helpers.errorResponse.badRequest,
                                        },
                                        errorResponse: {
                                            fileName: "errorResponse.js",
                                            content: contentWriter_1.helpers.errorResponse.errorResponse,
                                        },
                                        notFound: {
                                            fileName: "notFound.js",
                                            content: contentWriter_1.helpers.errorResponse.notFound,
                                        },
                                        precondition: {
                                            fileName: "precondition.js",
                                            content: contentWriter_1.helpers.errorResponse.precondition,
                                        },
                                        unauthorized: {
                                            fileName: "unauthorized.js",
                                            content: contentWriter_1.helpers.errorResponse.unauthorized,
                                        },
                                        unhandled: {
                                            fileName: "unhandled.js",
                                            content: contentWriter_1.helpers.errorResponse.unhandled,
                                        },
                                    },
                                ],
                            },
                        },
                    ],
                },
                {
                    folder: "middlewares",
                    files: [
                        {
                            index: { fileName: "index.js", content: contentWriter_1.middlewares.index },
                            authorization: {
                                fileName: "authorization.js",
                                content: contentWriter_1.middlewares.authorization,
                            },
                            validation: {
                                fileName: "validation.js",
                                content: contentWriter_1.middlewares.validation,
                            },
                        },
                    ],
                },
                {
                    folder: "database",
                    files: [
                        {
                            files: [
                                { index: { fileName: "index.js", content: contentWriter_1.database.index } },
                            ],
                        },
                        {
                            folder: "models",
                            files: [
                                {
                                    modelName: {
                                        fileName: "users.model.js",
                                        content: contentWriter_1.database.models.modelName,
                                    },
                                },
                            ],
                        },
                        {
                            folder: "seeders",
                            files: [
                                {
                                    index: {
                                        fileName: "update.seeder.js",
                                        content: contentWriter_1.database.seeders.updateSeeder,
                                    },
                                },
                            ],
                        },
                    ],
                },
                {
                    folder: "public",
                    files: [
                        {
                            index: {
                                fileName: "index.html",
                                content: `<h1>Hello, ${appName}</h1>`,
                            },
                        },
                        {
                            folder: "client",
                            files: [
                                {
                                    client: { fileName: "client.js", content: "client app" },
                                },
                            ],
                        },
                        {
                            folder: "images",
                        },
                    ],
                },
                {
                    folder: "routes",
                    files: [
                        {
                            index: { fileName: "index.js", content: contentWriter_1.routes.index },
                        },
                    ],
                },
                {
                    folder: "modules",
                    files: [
                        {
                            folder: "users",
                            files: [
                                {
                                    index: { fileName: "index.js", content: contentWriter_1.modules.users.index },
                                    usersRoutes: {
                                        fileName: "users.routes.js",
                                        content: contentWriter_1.modules.users.usersRoutes,
                                    },
                                    usersController: {
                                        fileName: "users.controller.js",
                                        content: contentWriter_1.modules.users.usersController,
                                    },
                                    usersService: {
                                        fileName: "users.service.js",
                                        content: contentWriter_1.modules.users.usersService,
                                    },
                                    usersValidation: {
                                        fileName: "users.validation.js",
                                        content: contentWriter_1.modules.users.usersValidation,
                                    },
                                },
                            ],
                        },
                    ],
                },
                {
                    folder: "utils",
                    files: [
                        {
                            index: { fileName: "index.js", content: contentWriter_1.utils.index },
                            jwt: { fileName: "jwt.js", content: contentWriter_1.utils.jwt },
                            logger: { fileName: "logger.js", content: contentWriter_1.utils.logger },
                            emailTemplates: {
                                folder: "emailTemplates",
                                files: [
                                    {
                                        index: {
                                            fileName: "email.html",
                                            content: `<h1>Email Template for ${appName}</h1>`,
                                        },
                                    },
                                ],
                            },
                        },
                    ],
                },
            ],
        },
    };
});
exports.default = PROJECT_DIR;
